/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Runs the regressions on the set of individuals for which we can determine if they were ever parents to determine the male-female earnings / employment gap, how this gap differs for women who are/are not ever mothers, and how this gap differs based on the number of children that a woman has.  Uses these differences based on the number of children to determine the birth penalty associated with each additional childbirth.

	OUTPUT DATASETS:
Output:
	- outputs.earn_gap_reg_counts
	- outputs.emp_gap_reg_counts
	- outputs.earn_birth_penalty_reg_counts
	- outputs.emp_birth_penalty_reg_counts
	- outputs.earn_birth_penalty_reg_counts0
	- outputs.emp_birth_penalty_reg_counts0
	- outputs.earn_birth_penalty_reg_counts1
	- outputs.emp_birth_penalty_reg_counts1

Final Output:
	- outputs.gen_fq_earn_gap_baseline
	- outputs.gen_fq_emp_gap_baseline
	- outputs.gen_fq_earn_evermom
	- outputs.gen_fq_emp_evermom
	- outputs.gen_fq_earn_gap_evermom
	- outputs.gen_fq_emp_gap_evermom
	- outputs.gen_fq_earn_gap_evermom_ctrl
	- outputs.gen_fq_emp_gap_evermom_ctrl
	- outputs.birth_penalty_fq_earn
	- outputs.birth_penalty_fq_emp
	- outputs.gen_earn_gap_baseline_fq_race
	- outputs.gen_earn_gap_baseline_fq_ed
	- outputs.gen_earn_evermom_fq_race
	- outputs.gen_earn_evermom_fq_ed
	- outputs.gen_earn_gap_evermom_fq_race
	- outputs.gen_earn_gap_evermom_fq_ed
	- outputs.gen_earn_evermom_ctrl_fq_race
	- outputs.gen_earn_evermom_ctrl_fq_ed
	- outputs.gen_earn_gap_evermom_ctrl_fq_race
	- outputs.gen_earn_gap_evermom_ctrl_fq_ed
	- outputs.birth_penalty_fq_race
	- outputs.birth_penalty_fq_ed 
*********************************************************************************************/

%let num_obs = MAX;

proc sort data=interwrk.ever_parent_earnfq_hist( obs=&num_obs.);
    by sex ever_parent educ_c;
run;
    

data tmp_for_analysis (keep=ln_earn_r emp_status educ_c age age_q sex F_c_num M_c_num race_eth sex  is_female qtime n_children c_birth_age1-c_birth_age4 birth_qt  );
    length ln_earn_r 5 race_eth $2 
           F_c_num M_c_num is_female emp_status 3;
    set interwrk.ever_parent_earnfq_hist ( obs=&num_obs.);
    
    array earn_r_a {300} earn_fq_r_age1-earn_fq_r_age300;
    array ln_earn_r_age {300};

    array emp_age {300};

    array qtime_a {300};
        
    race_eth = cats(race, ethnicity);

    if sex = "M" then do;
        is_female = 0;
        M_c_num = n_children;
        F_c_num = -1;
    end;
    if sex = "F" then do;
        is_female = 1;
        F_c_num = n_children;
        M_c_num = -1;
    end;
    

    do i = 72 to 216;

        age_q = i;    
        age = i/4;
        qtime = birth_qt  + i;
        emp_status = .;
        ln_earn_r = .;
    
        if (1990-1985)*4+1 <= birth_qt + i <= (2018-1985)*4+4 then do;
            emp_status = 0;
        end;
 
        if earn_r_a{i} > 0 then do;
            ln_earn_r = log(earn_r_a{i});
            * if the person could have had earnings in this time frame;
            if (1990-1985)*4+1 <= birth_qt + i <= (2018-1985)*4+4 then do;
                emp_status  = 1;
            end;
        end;
            

        if emp_status ~= . and educ_c ~= "U" and sex ~= "U" and race ~= "U" and ethnicity ~= "U" and n_children <=4 then output;
    end;
        
run;
    
*proc print data=tmp_for_analysis(obs=500);

proc sort data=tmp_for_analysis;
    by race_eth age;
run;

proc contents data=tmp_for_analysis;
proc print data=tmp_for_analysis(obs=20);

%macro prep_data;
data tmp_for_earn_analysis2 /view=tmp_for_earn_analysis2;
    set tmp_for_analysis;
    where ln_earn_r ~= .;
    
    array birth1_a {77} 3;
    array birth2_a {77} 3;
    array birth3_a {77} 3;
    array birth4_a {77} 3;
    
    do j =  1 to 77;
        birth1_a{j} = 0;
        birth2_a{j} = 0;
        birth3_a{j} = 0;
        birth4_a{j} = 0;    
    end;
    
    %do k =  1 %to 4;
        if c_birth_age&k. ~= . and sex="F" then do;
            if c_birth_age&k. -4 <=  age_q <= c_birth_age&k. + 72 then do;
                
               birth&k._a{ age_q - c_birth_age&k. +5} = 1;
                
            end;
        end;
    %end;
run;   

data tmp_for_emp_analysis2 /view=tmp_for_emp_analysis2;
    set tmp_for_analysis;
    
    array birth1_a {77} 3;
    array birth2_a {77} 3;
    array birth3_a {77} 3;
    array birth4_a {77} 3;
    
    do j =  1 to 77;
        birth1_a{j} = 0;
        birth2_a{j} = 0;
        birth3_a{j} = 0;
        birth4_a{j} = 0;    
    end;
    
    %do k =  1 %to 4;
        if c_birth_age&k. ~= . and sex="F" then do;
            if c_birth_age&k. -4 <=  age_q <= c_birth_age&k. + 72 then do;
                
               birth&k._a{ age_q - c_birth_age&k. +5} = 1;
                
            end;
        end;
    %end;

    r = rand("Uniform");
    
    if r <= 0.25 then output;
run;   
    
    
   %mend;
        %prep_data;
    
%macro run_all_reg(out_lbl, outcome_var);

proc glm data=tmp_for_analysis;
    absorb race_eth age;
    class F_c_num educ_c(ref="2")  qtime age ;
    model &outcome_var. = age is_female*age educ_c*age  qtime /solution  noint;
    ods output ParameterEstimates=temp.tmp_fq_&out_lbl._results1 NOBS=temp.tmp_fq_&out_lbl._obs1;
run;

    
        

proc glm data=tmp_for_analysis;
    absorb race_eth age;
    class F_c_num(ref="-1") educ_c(ref="2")  qtime age ;
    model &outcome_var. = F_c_num*age educ_c*age  qtime /solution noint;
    ods output ParameterEstimates=temp.tmp_fq_&out_lbl._results2 NOBS=temp.tmp_fq_&out_lbl._obs2;
run;      

%if  "&out_lbl." = "earn" %then %do;        
    proc freq data=tmp_for_analysis(where=(race_eth~="" and age~=. and qtime ~= . and educ_c ~= "" and F_c_num ~= .));
        table age*F_c_num /out=outputs.&out_lbl._gap_reg_counts ;
    run;
%end;

%if  "&out_lbl." = "emp" %then %do;        
    proc freq data=tmp_for_analysis(where=(race_eth~="" and age~=. and qtime ~= . and educ_c ~= "" and F_c_num ~= .));
        table emp_status*age*F_c_num /out=outputs.&out_lbl._gap_reg_counts ;
    run;
%end;

proc glm data=tmp_for_&out_lbl._analysis2;
    absorb race_eth age;
    class F_c_num(ref="-1") educ_c(ref="2")  qtime age ;
    model &outcome_var. = F_c_num*age educ_c*age  qtime birth1_a1-birth1_a77  birth2_a1-birth2_a77  birth3_a1-birth3_a77  birth4_a1-birth4_a77 /solution noint;
    ods output ParameterEstimates=temp.tmp_fq_&out_lbl._results3 NOBS=temp.tmp_fq_&out_lbl._obs3;
run;

%if  "&out_lbl." = "earn" %then %do;        
proc summary data=tmp_for_&out_lbl._analysis2(where=(race_eth~="" and age~=. and qtime ~= . and educ_c ~= "" and F_c_num ~= .));
    var birth1_a1-birth1_a77 birth2_a1-birth2_a77 birth3_a1-birth3_a77 birth4_a1-birth4_a77 ;
    output out=outputs.&out_lbl._birth_penalty_reg_counts sum= /autoname ;
run;
%end;

%if  "&out_lbl." = "emp" %then %do;
proc summary data=tmp_for_&out_lbl._analysis2(where=(race_eth~="" and age~=. and qtime ~= . and educ_c ~= "" and F_c_num ~= . and emp_status=0));
    var birth1_a1-birth1_a77 birth2_a1-birth2_a77 birth3_a1-birth3_a77 birth4_a1-birth4_a77 ;
    output out=outputs.&out_lbl._birth_penalty_reg_counts0 sum= /autoname ;
run;

proc summary data=tmp_for_&out_lbl._analysis2(where=(race_eth~="" and age~=. and qtime ~= . and educ_c ~= "" and F_c_num ~= . and emp_status=1));
    var birth1_a1-birth1_a77 birth2_a1-birth2_a77 birth3_a1-birth3_a77 birth4_a1-birth4_a77 ;
    output out=outputs.&out_lbl._birth_penalty_reg_counts1 sum= /autoname ;
run;
%end;   


*proc contents data=temp.tmp_&out_lbl._results1;
*proc print    data=temp.tmp_&out_lbl._results1;

data outputs.gen_fq_&out_lbl._gap_baseline;
    set temp.tmp_fq_&out_lbl._results1;
    
    if substr(parameter,1,9) = "is_female" then do;
        age = input(strip(substr(parameter,14)),5.);
    
        output;
    end;

proc print    data=outputs.gen_fq_&out_lbl._gap_baseline;
ods graphics on /reset imagename="F_fq_&out_lbl._gap_baseline" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.gen_fq_&out_lbl._gap_baseline;
    series x=age y=estimate ;
run;     
ods graphics off;

*proc contents data=temp.tmp_fq_&out_lbl._results2;
*proc print    data=temp.tmp_fq_&out_lbl._results2;
        
        data outputs.gen_fq_&out_lbl._evermom;
    length ptype $2;
    set temp.tmp_fq_&out_lbl._results2;
    
    if substr(parameter,1,7) = "F_c_num" then do;
        if substr(parameter,13,2) = "-1" then ptype = "M";
        else if substr(parameter,13,1) = "0" then ptype = "F0";
        else if substr(parameter,13,1) = "1" then ptype = "F1";
        else if substr(parameter,13,1) = "2" then ptype = "F2";
        else if substr(parameter,13,1) = "3" then ptype = "F3";
        else if substr(parameter,13,1) = "4" then ptype = "F4";
   
        
        age = input(strip(substr(parameter,15)),5.);
    
        output;
    end;

proc print    data=outputs.gen_fq_&out_lbl._evermom;

ods graphics on /reset imagename="F_fq_&out_lbl._ever_mom" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.gen_fq_&out_lbl._evermom;
    series x=age y=estimate /group=ptype;
run;     
ods graphics off;


* construct the  gap  with  male earnings;
proc  sort data=outputs.gen_fq_&out_lbl._evermom;
    by descending ptype;
run;
    
data outputs.gen_fq_&out_lbl._gap_evermom;
    set outputs.gen_fq_&out_lbl._evermom;

    array m_earn {300} _temporary_;
    
    age_q = age*4;
    
    if ptype = "M" then do;
        m_earn{age_q} = estimate;
    end;
    else do;
        estimate_gap = estimate - m_earn{age_q};
        output;
    end;
run;
        
    ods graphics on /reset imagename="F_fq_&out_lbl._gap_ever_mom" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.gen_fq_&out_lbl._gap_evermom;
    series x=age y=estimate_gap /group=ptype;
run;     
ods graphics off;



proc contents data=temp.tmp_fq_&out_lbl._results3;
proc print    data=temp.tmp_fq_&out_lbl._results3;

* birth adjusted, earnings gap  by number of children;        
        data outputs.gen_fq_&out_lbl._gap_evermom_ctrl;
    length ptype $2;
    set temp.tmp_fq_&out_lbl._results3;
    
    if substr(parameter,1,7) = "F_c_num" then do;
        if substr(parameter,13,2) = "-1" then ptype = "M";
        else if substr(parameter,13,1) = "0" then ptype = "F0";
        else if substr(parameter,13,1) = "1" then ptype = "F1";
        else if substr(parameter,13,1) = "2" then ptype = "F2";
        else if substr(parameter,13,1) = "3" then ptype = "F3";
        else if substr(parameter,13,1) = "4" then ptype = "F4";
   
        
        age = input(strip(substr(parameter,15)),5.);
    
        output;
    end;

proc print    data=outputs.gen_fq_&out_lbl._gap_evermom_ctrl;
ods graphics on /reset imagename="F_fq_&out_lbl._gap_ever_mom_ctrl" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.gen_fq_&out_lbl._gap_evermom_ctrl;
    series x=age y=estimate /group=ptype;
run;     
ods graphics off;


* birth penalty;        
data outputs.birth_penalty_fq_&out_lbl.;
    length ptype $2;
    set temp.tmp_fq_&out_lbl._results3;
    
    if substr(parameter,1,5) = "birth" then do;

        birth_num = input(strip(substr(parameter,6,1)),1.);
   
        
        y_since_birth = (input(strip(substr(parameter,9)),5.)-5)/4;
    
        output;
    end;
run;

ods graphics on /reset imagename="M_birth_penalty_fq_&out_lbl." imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.birth_penalty_fq_&out_lbl.;
    series x=y_since_birth y=estimate /group=birth_num;
run;     
ods graphics off;

%mend;

%run_all_reg(earn, ln_earn_r);
%run_all_reg(emp, emp_status);









* BY CHARACTERISTICS ANALYSIS;

%macro run_by_regs(lbl, by_var,  non_by_var, non_by_var_ref);

proc sort data=tmp_for_analysis;
    by &by_var.;
run;

proc glm data=tmp_for_analysis;
    by &by_var.;
    class F_c_num &non_by_var.(ref="&non_by_var_ref.")  qtime age  ;
    model ln_earn_r = age is_female*age &non_by_var.*age  qtime /solution  noint;
    ods output ParameterEstimates=temp.tmp_results_fq_&lbl.1 NOBS=temp.tmp_obs_fq_&lbl.1;
run;

    
        

proc glm data=tmp_for_analysis;
    by &by_var.;
    class F_c_num(ref="-1") &non_by_var.(ref="&non_by_var_ref.")  qtime age  ;
    model ln_earn_r = F_c_num*age &non_by_var.*age  qtime /solution  noint;
    ods output ParameterEstimates=temp.tmp_results_fq_&lbl.2 NOBS=temp.tmp_obs_fq_&lbl.2; 
run;      
        


proc glm data=tmp_for_earn_analysis2;  
    by &by_var.;
    class F_c_num(ref="-1") &non_by_var.(ref="&non_by_var_ref.")  qtime age  ;
    model ln_earn_r = F_c_num*age &non_by_var.*age  qtime birth1_a1-birth1_a77  birth2_a1-birth2_a77  birth3_a1-birth3_a77  birth4_a1-birth4_a77 /solution  noint;
    ods output ParameterEstimates=temp.tmp_results_fq_&lbl.3 NOBS=temp.tmp_obs_fq_&lbl.3;
run;

    


*proc contents data=temp.tmp_results_fq_&lbl.1;
*proc print    data=temp.tmp_results_fq_&lbl.1;

data outputs.gen_earn_gap_baseline_fq_&lbl.;
    set temp.tmp_results_fq_&lbl.1;    
    %if "&lbl." = "race" %then %do;
        where race_eth = "1N" or race_eth="2N"  or race_eth = "4N"  or race_eth = "1H";
    %end;
    
    if substr(parameter,1,9) = "is_female" then do;
        age = input(strip(substr(parameter,14)),5.);
    
        output;
    end;

proc print    data=outputs.gen_earn_gap_baseline_fq_&lbl.;
*ods graphics on /reset imagename="F_earn_gap_baseline_fq_&lbl." imagefmt=pdf;
*ods listing gpath = "&figure_path.";
*proc sgplot data=outputs.gen_earn_gap_baseline_fq_&lbl.;
*    series x=age y=estimate /group=&by_var.;
*    rowaxis min=-0.8 max=0.2;
*run;     
*ods graphics off;

*proc contents data=temp.tmp_results_fq_&lbl.2;
*proc print    data=temp.tmp_results2_fq_&lbl.2;
        
        data outputs.gen_earn_evermom_fq_&lbl.;
    length ptype $2;
    set temp.tmp_results_fq_&lbl.2;         
    %if "&lbl." = "race" %then %do;
        where race_eth = "1N" or race_eth="2N"  or race_eth = "4N"  or race_eth = "1H";
    %end;

    if substr(parameter,1,7) = "F_c_num" then do;
    
    %if "&lbl." = "race" %then %do;
        if substr(parameter,13,2) = "-1" then ptype = "M";
        else if substr(parameter,13,1) = "0" then ptype = "F0";
        else if substr(parameter,13,1) = "1" then ptype = "F1";
        else if substr(parameter,13,1) = "2" then ptype = "F2";
        else if substr(parameter,13,1) = "3" then ptype = "F3";
        else if substr(parameter,13,1) = "4" then ptype = "F4";
    
        
        age = input(strip(substr(parameter,15)),5.);
    %end;
    %if "&lbl." = "ed" %then %do;
        if substr(parameter,14,2) = "-1" then ptype = "M";
        else if substr(parameter,14,1) = "0" then ptype = "F0";
        else if substr(parameter,14,1) = "1" then ptype = "F1";
        else if substr(parameter,14,1) = "2" then ptype = "F2";
        else if substr(parameter,14,1) = "3" then ptype = "F3";
        else if substr(parameter,14,1) = "4" then ptype = "F4";
    
        
        age = input(strip(substr(parameter,16)),5.);
    %end;

        output;
    end;

proc print    data=outputs.gen_earn_evermom_fq_&lbl.;

ods graphics on /reset imagename="F_earn_ever_mom_fq_&lbl." imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgpanel data=outputs.gen_earn_evermom_fq_&lbl.;
    panelby &by_var.;
    series x=age y=estimate /group=ptype;
run;     
ods graphics off;


* construct the  gap  with  male earnings;
proc  sort data=outputs.gen_earn_evermom_fq_&lbl.;
    by &by_var. descending ptype;
run;
    
data outputs.gen_earn_gap_evermom_fq_&lbl.;
    set outputs.gen_earn_evermom_fq_&lbl.;

    array m_earn {300} _temporary_;
    
    age_q = age*4;
    
    if ptype = "M" then do;
        m_earn{age_q} = estimate;
    end;
    else do;
        estimate_gap = estimate - m_earn{age_q};
        output;
    end;
run;
        
    ods graphics on /reset imagename="F_earn_gap_ever_mom_fq_&lbl." imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgpanel data=outputs.gen_earn_gap_evermom_fq_&lbl.;
    panelby &by_var.;
    series x=age y=estimate_gap /group=ptype;
    rowaxis min=-0.8 max=0.2;
run;     
ods graphics off;



proc contents data=temp.tmp_results_fq_&lbl.3;
proc print    data=temp.tmp_results_fq_&lbl.3;

* birth adjusted, earnings gap  by number of children;        
        data outputs.gen_earn_mom_ctrl_fq_&lbl.;
    length ptype $2;
    set temp.tmp_results_fq_&lbl.3;   
    %if "&lbl." = "race" %then %do;
        where race_eth = "1N" or race_eth="2N" or race_eth = "4N"  or race_eth = "1H";
    %end;
    
    if substr(parameter,1,7) = "F_c_num" then do;

    %if "&lbl." = "race" %then %do;
        if substr(parameter,13,2) = "-1" then ptype = "M";
        else if substr(parameter,13,1) = "0" then ptype = "F0";
        else if substr(parameter,13,1) = "1" then ptype = "F1";
        else if substr(parameter,13,1) = "2" then ptype = "F2";
        else if substr(parameter,13,1) = "3" then ptype = "F3";
        else if substr(parameter,13,1) = "4" then ptype = "F4";
    
        
        age = input(strip(substr(parameter,15)),5.);
    %end;
    %if "&lbl." = "ed" %then %do;
        if substr(parameter,14,2) = "-1" then ptype = "M";
        else if substr(parameter,14,1) = "0" then ptype = "F0";
        else if substr(parameter,14,1) = "1" then ptype = "F1";
        else if substr(parameter,14,1) = "2" then ptype = "F2";
        else if substr(parameter,14,1) = "3" then ptype = "F3";
        else if substr(parameter,14,1) = "4" then ptype = "F4";
    
        
        age = input(strip(substr(parameter,16)),5.);
    %end;
    
    
        output;
    end;

proc print    data=outputs.gen_earn_mom_ctrl_fq_&lbl.;
ods graphics on /reset imagename="F_earn_ever_mom_ctrl_fq_&lbl." imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgpanel data=outputs.gen_earn_mom_ctrl_fq_&lbl.;
    panelby &by_var.;
    series x=age y=estimate /group=ptype;
    
run;     
ods graphics off;



* construct the  gap  with  male earnings;
proc  sort data=outputs.gen_earn_mom_ctrl_fq_&lbl.;
    by &by_var. descending ptype;
run;
    
data outputs.gen_earn_gap_mom_ctrl_fq_&lbl.;
    set outputs.gen_earn_mom_ctrl_fq_&lbl.;

    array m_earn {300} _temporary_;
    
    age_q = age*4;
    
    if ptype = "M" then do;
        m_earn{age_q} = estimate;
    end;
    else do;
        estimate_gap = estimate - m_earn{age_q};
        output;
    end;
run;
        
    ods graphics on /reset imagename="F_earn_gap_ever_mom_ctrl_fq_&lbl." imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgpanel data=outputs.gen_earn_gap_mom_ctrl_fq_&lbl.;
    panelby &by_var.;
    series x=age y=estimate_gap /group=ptype;
    rowaxis min=-0.8 max=0.2;
run;     
ods graphics off;

* birth penalty;        
data outputs.birth_penalty_fq_&lbl.;
    length ptype $2;
    set temp.tmp_results_fq_&lbl.3;   
    %if "&lbl." = "race" %then %do;
        where race_eth = "1N" or race_eth="2N" or race_eth = "4N" or race_eth = "1H";
    %end;
    
    if substr(parameter,1,5) = "birth" then do;

        birth_num = input(strip(substr(parameter,6,1)),1.);
   
        
        y_since_birth = (input(strip(substr(parameter,9)),5.)-5)/4;
    
        output;
    end;
run;

ods graphics on /reset imagename="M_birth_penalty_fq_&lbl." imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgpanel data=outputs.birth_penalty_fq_&lbl.;
    panelby &by_var.;
    series x=y_since_birth y=estimate /group=birth_num;
run;     
ods graphics off;

%mend;
    
%run_by_regs(race, race_eth,  educ_c, 2);
%run_by_regs(ed, educ_c, race_eth, 1N );

