*------------------------------------------------------------------------------------------*
*	FIGURE 10
*------------------------------------------------------------------------------------------*
{
*define outcome variables
global covars c.age#i.educ c.age2#i.educ

*define parameters for panel data
	*annual
	local t_pre_annual=3
	local t_back_annual=4
	local t_forward_annual=4
	local t_unit_annual=1
	*quarterly
	local t_pre_quarterly=7
	local t_back_quarterly=8
	local t_forward_quarterly=12
	local t_unit_quarterly=4 

*define sample size
local freq quarterly
local samplesize r(p25)

*define number of significant digits
global sigdignum=3
	
*define outcome variable 
local y earn_total

*load data
use "${datatemp}evenstudypanel_`freq'.dta", clear

*for quarterly data use subsample to reduce computational burden
if "`freq'"=="quarterly" {
	sum uniform, detail
	keep if uniform<``samplesize''
}

sum firmsize, detail
gen firmsize_q = cond(firmsize==.,.,cond(firmsize<20,1,cond(firmsize<50,2, ///
	cond(firmsize<250,3,cond(firmsize<500,4,5)))))
tab firmsize_q, mi
tab t

forvalues m=1/5 {
gen temp_flag = cond(parent_flag==1 & firmsize_q==`m',1,0)
egen sample_flag = max(temp_flag), by(coworkerfe)
reghdfe `y' d_f* $covars if sample_flag==1, absorb(pik_fe i.coworkerfe##i.t) vce(cluster coworkerfe)
foreach var of varlist d_f* {
	scalar m`m'_b_`var'  = _b[`var']
	scalar m`m'_se_`var'  = _se[`var']
}
drop temp_flag sample_flag
}
local m=6
gen temp_flag = cond(num_estabs==1,1,0)
egen sample_flag = max(temp_flag), by(coworkerfe)
reghdfe `y' d_f* $covars if sample_flag==1, absorb(pik_fe i.coworkerfe##i.t) vce(cluster coworkerfe)
foreach var of varlist d_f* {
	scalar m`m'_b_`var'  = _b[`var']
	scalar m`m'_se_`var'  = _se[`var']
}
drop temp_flag sample_flag


*save output
keep t top3_f_ratio
duplicates drop
forvalues m=1/6 {
	gen double m`m'_b = .
	gen double m`m'_se = .
}
sum t, detail
forvalues m=1/6 {
forvalues t=`t_pre_`freq''/`r(max)' {
forvalues f=0/3 {
	replace m`m'_b = scalar(m`m'_b_d_f`f'_t`t') if t==`t' & top3_f_ratio==`f'
	replace m`m'_se = scalar(m`m'_se_d_f`f'_t`t') if t==`t' & top3_f_ratio==`f'
}
}
}
replace t = t-`t_back_`freq''-1-`t_unit_`freq''
keep if t>=-6
forvalues m=1/6 {
sigdigitsvar, val_sd(m`m'_b) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(m`m'_se) sigdigit_sd($sigdignum)
}

tempfile temp 
save `temp'


local type firmsize
local lab1 a
local lab2 b 
local lab3 c 
local lab4 d
local lab5 e
local lab6 f
foreach x in birthorder education race preearnings {
	local m_`x'=4
	local int_`x'=1000
}
local int_firmsize=1000
local int_preearnings=2000
local m_firmsize=6
local ymin_birthorder=-4000
local ymin_race=-4000
local ymin_preearnings=-6000
local ymin_education=-4000
local ymin_firmsize=-4000
use `temp', clear
drop if t<-6
sort t
forvalues m=1/`m_`type'' {
gen upper = m`m'_b+1.96*m`m'_se
gen lower = m`m'_b-1.96*m`m'_se
local selist
forvalues f=0/3 {
	local selist `selist' (connected upper t if top3_f_ratio==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
	local selist `selist' (connected lower t if top3_f_ratio==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
}
graph twoway `selist' ///
	(connected m`m'_b t if top3_f_ratio==0, color(gs0) msymbol(circle) graphregion(color(white))) ///
	(connected m`m'_b t if top3_f_ratio==1, color(gs3) msymbol(square) graphregion(color(white))) ///
	(connected m`m'_b t if top3_f_ratio==2, color(gs6) msymbol(triangle) graphregion(color(white))) ///
	(connected m`m'_b t if top3_f_ratio==3, color(gs9) msymbol(diamond) graphregion(color(white))), ///
	legend(label(9 "Zero") label(10 "One") label(11 "Two") label(12 "Three") order(9 10 11 12) ///
	title("Top three earners female", color(black) size(medium)) region(lcolor(white))) ///
	xtitle("Quarters after birth of child") ytitle("Quarterly earnings") ///
	yscale(range(`ymin_`type'' 1000)) ylabel(`ymin_`type''[`int_`type'']1000) ///
	xscale(range(-6 8)) xlabel(-6[2]8)
graph export "${tables_figures}figure_10`lab`m''.pdf", replace as(pdf)
drop upper lower
}
}
*end section 
