*------------------------------------------------------------------------------------------*
* FIGURES 4 AND 5
*------------------------------------------------------------------------------------------*
{

local earn_total_lab "a"
local earn_positive_lab "b"

local lab_earn_total "Quarterly earnings"	
local lab_earn_positive "Positive earnings"

*define outcome variables
global covars c.age#i.educ c.age2#i.educ

*define parameters for panel data
	*annual
	local t_pre_annual=3
	local t_back_annual=4
	local t_forward_annual=4
	local t_unit_annual=1
	*quarterly
	local t_pre_quarterly=7
	local t_back_quarterly=8
	local t_forward_quarterly=12
	local t_unit_quarterly=4 

*define sample size
local freq quarterly
local samplesize r(p25)

*define number of significant digits
global sigdignum=3

*estimate for total earnings and indicator for positive earnings
foreach y in earn_total earn_positive {

*load data
use "${datatemp}evenstudypanel_`freq'.dta", clear

*for quarterly data use subsample to reduce computational burden
if "`freq'"=="quarterly" {
	sum uniform, detail
	keep if uniform<``samplesize''
}

tab t

gen earn_positive = cond(earn_total>0,1,0)

*model 1
reghdfe `y' d_f* $covars, absorb(pik_fe i.coworkerfe##i.t) vce(cluster coworkerfe)
keep if e(sample)==1
foreach var of varlist d_f* {
	scalar m1_b_`var'  = _b[`var']
	scalar m1_se_`var'  = _se[`var']
}

keep t top3_f_ratio `y' parent_flag
gen `y'_sd = `y'
collapse (mean) `y' (sd) `y'_sd, by(t top3_f_ratio parent_flag) fast
sort t top3_f_ratio parent_flag
order t top3_f_ratio parent_flag `y' `y'_sd
sigdigitsvar, val_sd(`y') sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(`y'_sd) sigdigit_sd($sigdignum)
preserve
replace t = t-`t_back_`freq''-1-`t_unit_`freq''

sort t
graph twoway (connected `y' t if top3_f_ratio==0 & parent_flag==1, color(gs0) msymbol(circle) graphregion(color(white))) ///
	(connected `y' t if top3_f_ratio==1 & parent_flag==1, color(gs3) msymbol(square) graphregion(color(white))) ///
	(connected `y' t if top3_f_ratio==2 & parent_flag==1, color(gs6) msymbol(triangle) graphregion(color(white))) ///
	(connected `y' t if top3_f_ratio==3 & parent_flag==1, color(gs9) msymbol(diamond) graphregion(color(white))) ///
	(connected `y' t if top3_f_ratio==0 & parent_flag==0, color(gs0) msymbol(none) lpattern(dash)graphregion(color(white))) ///
	(connected `y' t if top3_f_ratio==1 & parent_flag==0, color(gs3) msymbol(none) lpattern(dash) graphregion(color(white))) ///
	(connected `y' t if top3_f_ratio==2 & parent_flag==0, color(gs6) msymbol(none) lpattern(dash) graphregion(color(white))) ///
	(connected `y' t if top3_f_ratio==3 & parent_flag==0, color(gs9) msymbol(none) lpattern(dash) graphregion(color(white))), ///
	legend(label(1 "Zero") label(2 "One") label(3 "Two") label(4 "Three") order(1 2 3 4) ///
	title("Top three earners female", color(black) size(medium)) region(lcolor(white))) ///
	xtitle("Quarters after birth of child") ytitle("`lab_`y''") ///
	xscale(range(-12 8)) xlabel(-12[2]8)
graph export "${tables_figures}figure_4`y_lab'.pdf", replace as(pdf)

restore 
keep t top3_f_ratio
duplicates drop
forvalues m=1/1 {
	gen double m`m'_b = .
	gen double m`m'_se = .
}
sum t, detail
forvalues m=1/1 {
forvalues f=0/3 {
forvalues t=`t_pre_`freq''/`r(max)' {
	replace m`m'_b = scalar(m`m'_b_d_f`f'_t`t') if t==`t' & top3_f_ratio==`f'
	replace m`m'_se = scalar(m`m'_se_d_f`f'_t`t') if t==`t' & top3_f_ratio==`f'
}
}
}
replace t = t-`t_back_`freq''-1-`t_unit_`freq''
keep if t>=-6
forvalues m=1/1 {
sigdigitsvar, val_sd(m`m'_b) sigdigit_sd($sigdignum)
sigdigitsvar, val_sd(m`m'_se) sigdigit_sd($sigdignum)
}

drop if t<-6
sort t
forvalues m=1/1 {
gen upper = m`m'_b+1.96*m`m'_se
gen lower = m`m'_b-1.96*m`m'_se
local selist
forvalues f=0/3 {
	local selist `selist' (connected upper t if top3_f_ratio==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
	local selist `selist' (connected lower t if top3_f_ratio==`f', lpattern(dash) msymbol(none) lcolor(gs12) graphregion(color(white)))
}
graph twoway `selist' ///
	(connected m`m'_b t if top3_f_ratio==0, color(gs0) msymbol(circle) graphregion(color(white))) ///
	(connected m`m'_b t if top3_f_ratio==1, color(gs3) msymbol(square) graphregion(color(white))) ///
	(connected m`m'_b t if top3_f_ratio==2, color(gs6) msymbol(triangle) graphregion(color(white))) ///
	(connected m`m'_b t if top3_f_ratio==3,  color(gs9) msymbol(diamond) graphregion(color(white))), ///
	legend(label(9 "Zero") label(10 "One") label(11 "Two") label(12 "Three") order(9 10 11 12) ///
	title("Top three earners female", color(black) size(medium)) region(lcolor(white))) ///
	xtitle("Quarters after birth of child") ytitle("`lab_`y''") ///
	xscale(range(-6 8)) xlabel(-6[2]8)
graph export "${tables_figures}figure_5`y_lab'.pdf", replace as(pdf)
drop upper lower
}

}
}
*end section
