*------------------------------------------------------------------------------------------*
*	TABLE 3
*------------------------------------------------------------------------------------------*
{
*define outcome variables
global covars c.age#i.educ c.age2#i.educ

*define parameters for panel data
	*annual
	local t_pre_annual=3
	local t_back_annual=4
	local t_forward_annual=4
	local t_unit_annual=1
	*quarterly
	local t_pre_quarterly=7
	local t_back_quarterly=8
	local t_forward_quarterly=12
	local t_unit_quarterly=4 

*define sample size
local freq quarterly
local samplesize r(p25)

*define number of significant digits
global sigdignum=3

local outcomes sepne2yr empft1yrlater emp_at_samefid_yr3
local covars tenure_bck pre_lnearnings ethnicity race age educ_lhs educ_hs educ_sc educ_cp
	
use parent_flag uniform top3_f_ratio coworkerfe `outcomes' `covars'  ///
	using "${datatemp}cleandata_reg.dta", clear
sum uniform, detail
keep if uniform<``samplesize''
gen educ = cond(educ_lhs==1,1,cond(educ_hs==1,2,cond(educ_sc==1,3,cond(educ_cp==1,4,0))))
gen age2=age^2
tab parent_flag, mi
replace top3_f_ratio=0 if parent_flag!=1
foreach x in ethnicity race {
	rename `x' temp
	egen `x' = group(temp)
	drop temp
}

*ESTIMATE REGRESSIONS WITH COWORKER FIXED EFFECTS
est clear
foreach y in `outcomes' {
tab `y', mi
*no covariates
reghdfe `y' i.parent_flag i.top3_f_ratio, absorb(coworkerfe) vce(cluster coworkerfe)
eststo, title("`y'")
*covariates 
reghdfe `y' i.parent_flag i.top3_f_ratio c.age#i.educ c.age2#i.educ tenure_bck pre_lnearnings i.ethnicity i.race ///
	, absorb(coworkerfe) vce(cluster coworkerfe)
eststo, title("`y'")
}
*export results

esttab using "${tables_figures}table_3.csv", replace ///
	keep(1.parent_flag 1.top3_f_ratio 2.top3_f_ratio 3.top3_f_ratio) cells(b se p) stats(N, fmt(%12.0g))  

import delimited "${tables_figures}table_3.csv", clear
gen obs=_n
forvalues v=2/7 {
forvalues r=4/15 {
	local r`r'_v`v'=subinstr(subinstr(v`v'[`r'],`"""',"",.),"=","",.)
	di "`r`r'_v`v''"
	sigdigits, val_sd(`r`r'_v`v'') sigdigit_sd($sigdignum)
	local r`r'_v`v'=`r(val_sigdig)'
	replace v`v'="`r`r'_v`v''" if obs==`r'
}
local r=16
local r`r'_v`v'=subinstr(subinstr(v`v'[`r'],`"""',"",.),"=","",.)
drbround, x(`r`r'_v`v'')
local r`r'_v`v'=`r(rounded)'
replace v`v'="`r`r'_v`v''" if obs==`r'
}
drop obs
export delimited "${tables_figures}table_3.csv", replace
}
*end section
