/*********************************************************************************************

	WRITTEN BY: MATTHEW STAIGER
		Extract the occupation code for each PIK in the ACS from 2001-2017.  Identify
		the survey quarter and generate the corresponding qtime for the occupation. 

	OUTPUT DATASET: interwrk.occupation
	       VARIABLES: pik qtime occ
*********************************************************************************************/

*SUMMARIZE INPUT DATA;
%macro acscontents;
%DO yr=2001 %TO 2011;
*person-level acs file;
PROC CONTENTS DATA=acs&yr..vpers&yr._1yr;
RUN;

*household-level acs file;
PROC CONTENTS DATA=acs&yr..vhous&yr._1yr;
RUN;

*PIK crosswalk;
PROC CONTENTS DATA=acsx&yr..crosswalk_acs&yr.;
RUN;
%END;

%DO yr=2016 %TO 2017;
*person-level acs file;
PROC CONTENTS DATA=acs&yr..acs&yr._vpers_1yr;
RUN;

*household-level acs file;
PROC CONTENTS DATA=acs&yr..acs&yr._vhous_1yr;
RUN;

*PIK crosswalk;
PROC CONTENTS DATA=acsx&yr..crosswalk_acs&yr.;
RUN;
%END;
%mend acscontents;
%acscontents;



*BRING IN OCCUPATION DATA FROM THE ACS;
*--------------------------------------------------------------------------------*;
%macro acsdata;

%let acsdata2001 = vpers2001_1yr;
%let acsdata2002 = vpers2002_1yr;
%let acsdata2003 = vpers2003_1yr;
%let acsdata2004 = vpers2004_1yr;
%let acsdata2005 = vpers2005_1yr;
%let acsdata2006 = vpers2006_1yr;
%let acsdata2007 = vpers2007_1yr;
%let acsdata2008 = vpers2008_1yr;
%let acsdata2009 = vpers2009_1yr;
%let acsdata2010 = vpers2010_1yr;
%let acsdata2011 = vpers2011_1yr;
%let acsdata2012 = vpers2012_1yr;
%let acsdata2013 = vpers2013_1yr;
%let acsdata2014 = vpers2014_1yr;
%let acsdata2015 = vpers2015_1yr;
%let acsdata2016 = acs2016_vpers_1yr;
%let acsdata2017 = acs2017_vpers_1yr;

%DO yr=2001 %TO 2017;

*there should be no duplicates here;
PROC SORT DATA=acs&yr..&&acsdata&yr(OBS=&sample_size. 
		KEEP=cmid pnum rdate occ WHERE=(occ^=""))
		OUT=acs 
		NODUPKEY;
	BY cmid pnum;
RUN;

PROC SORT DATA=acsx&yr..crosswalk_acs&yr.(OBS=&sample_size.)
		OUT=acsxwalk
		NODUPKEY;
	BY cmid pnum;
RUN;

DATA acs(KEEP=pik qtime occ);
	LENGTH pnum 8 occ $4.;
	MERGE acs(IN=source_acs) acsxwalk(IN=source_xwalk);
	BY cmid pnum;
	IF source_acs^=1 OR source_xwalk^=1 THEN DELETE;
	year=YEAR(rdate);
	month=MONTH(rdate);
	IF month>=1 AND month<=3 THEN quarter=1;
		IF month>=4 AND month<=6 THEN quarter=2;
		IF month>=7 AND month<=9 THEN quarter=3;
		IF month>=10 AND month<=12 THEN quarter=4;
	qtime=(year-1985)*4+quarter;
RUN;

*drop individuals with duplicates piks;
PROC SORT DATA=acs OUT=acs DUPOUT=dups(KEEP=pik) NODUPKEY;
	BY pik;
RUN;

PROC SORT DATA=dups NODUPKEY;
	BY pik;
RUN;

DATA acs;
	MERGE acs(IN=source_sample) dups(IN=source_dups);
	BY pik;
	IF source_dups=1 THEN DELETE;
RUN;

%IF &yr.=2001 %THEN %DO;
DATA occupation;
	SET acs;
RUN;
%END;

%IF &yr.>2001 %THEN %DO;

DATA occupation;
	SET occupation acs;
RUN;

%END;
%END;
%mend acsdata;
%acsdata;

*there should be no duplicates here;
PROC SORT DATA=occupation OUT=interwrk.occupation NODUPKEY;
	BY pik qtime;
RUN;

PROC CONTENTS DATA=interwrk.occupation;
RUN;

PROC PRINT DATA=interwrk.occupation(OBS=20);
RUN;
