/*********************************************************************************************

	WRITTEN BY: SETH MURRAY
		For each SEIN and qtime, calculates the top-earner(s) full-quarter earnings
		thresholds based on workers' 4-quarter moving average of full-quarter earnings.
		Creates files with these top-earner PIKs (looking forward and back 4 quarters
		in time) as well as the thresholds earnings levels.

 
	
	OUTPUT DATASET:
		interwrk.sein_top_earner_pik
		interwrk.sein_top_earner_fwd_pik
		interwrk.sein_top_earner_thresholds 
*********************************************************************************************/


%let num_obs = max;

data tmp_fq_earn_long1(keep=pik sein qtime fq_earn_4qma fq_earn_4qma_fwd)
     tmp_fq_earn_long2(keep=pik sein qtime fq_earn_4qma fq_earn_4qma_fwd)
     tmp_fq_earn_long3(keep=pik sein qtime fq_earn_4qma fq_earn_4qma_fwd)
     tmp_fq_earn_long4(keep=pik sein qtime fq_earn_4qma fq_earn_4qma_fwd)
     tmp_fq_earn_long5(keep=pik sein qtime fq_earn_4qma fq_earn_4qma_fwd);
    length e1-e20 5 qtime 3 fq_earn_4qma 5;
    set lehd_t13.phf_interleave_b (obs=&num_obs.);
    where pik ~= "000000000";
    
    array earn {&last_qtime.} e1-e&last_qtime.;
            
    array earn_ma4 {4} ;
    array earn_fwd_ma4 {4};
    
    do qtime = &first_qtime. to &last_qtime. - 1;
        do i = 1 to 4;
            earn_ma4{i} = .;
        end;
                
        * check if individual was employed for the full quarter;
        if earn{qtime+1} > 0 and earn{qtime} > 0 and earn{qtime -1} > 0 then  do;
            * get their FQ earnings in this quarter;
            earn_ma4{1} = earn{qtime};
            earn_fwd_ma4{1} = earn{qtime};
                     
            * and any of the last 3 quarters if they were employed for the full quarter;
            if earn{qtime} > 0 and earn{qtime-1} > 0 and earn{qtime -2} > 0 then  do;
                earn_ma4{2} = earn{qtime-1};
            end;
            if earn{qtime-1} > 0 and earn{qtime-2} > 0 and earn{qtime -3} > 0 then  do;
                earn_ma4{3} = earn{qtime-2};
            end;
            if earn{qtime-2} > 0 and earn{qtime-3} > 0 and earn{qtime -4} > 0 then  do;
                earn_ma4{4} = earn{qtime-3};
            end;
            
            * and any of the next 3 quarters if they were employed for the full quarter;
            if qtime <= &last_qtime. - 2 then do;
                if earn{qtime} > 0 and earn{qtime+1} > 0 and earn{qtime +2} > 0 then  do;
                    earn_fwd_ma4{2} = earn{qtime+1};
                end;
            end;
            if qtime <= &last_qtime. - 3 then do;
                if earn{qtime+1} > 0 and earn{qtime+2} > 0 and earn{qtime +3} > 0 then  do;
                    earn_fwd_ma4{3} = earn{qtime+2};
                end;
            end;
            if qtime <= &last_qtime. - 4 then do;
                if earn{qtime+2} > 0 and earn{qtime+3} > 0 and earn{qtime +4} > 0 then  do;
                    earn_fwd_ma4{4} = earn{qtime+3};
                end;
            end;
    
            fq_earn_4qma_fwd =  mean(of earn_fwd_ma4[*});
            fq_earn_4qma = mean(of earn_ma4[*});

            sein_num = input(substr(sein,1,2),2.);
            
            if sein_num < 10 then output tmp_fq_earn_long1;
            else if sein_num < 20 then output tmp_fq_earn_long2;
            else if sein_num < 30 then output tmp_fq_earn_long3;
            else if sein_num < 40 then output tmp_fq_earn_long4;
            else output tmp_fq_earn_long5;
                
        end;         
    end;
run;

%macro gen_top;            
    %do i =  1  %to 5;
        proc sort data=tmp_fq_earn_long&i.;
            by sein qtime descending fq_earn_4qma;
        run;

        proc contents data=tmp_fq_earn_long&i.;
        proc print data=tmp_fq_earn_long&i. (obs=20);
    
        * count the number of observations by qtime;
        proc summary data=tmp_fq_earn_long&i.;
            by sein qtime;
            var fq_earn_4qma fq_earn_4qma_fwd;
            output out=sein_earn_thresh&i. n= p99= p95= p90= max= /autoname;
        run;

    
* generate the firm level earnings thresholds;
data sein_top_earner_thresholds&i.(
              keep=sein qtime 
              fq_earn_4qma_top3 fq_earn_4qma_top1 fq_earn_4qma_n fq_earn_4qma_p99 fq_earn_4qma_p95 fq_earn_4qma_p90 fq_earn_4qma_fwd_top1
              top1_F_ratio top3_F_ratio p99_F_ratio p95_F_ratio p90_F_ratio
              allemp_F_ratio bp90_F_ratio male_avg_fq_earn_4qma female_avg_fq_earn_4qma allemp_avg_fq_earn_4qma)
    sein_top_earner_pik&i.(keep=sein pik qtime sex dob)
     sein_top_earner_fwd_pik&i.(keep=sein pik qtime fq_earn_4qma_n sex dob);
    length sex $1 dob 4 fq_earn_4qma_top3 fq_earn_4qma_top1 fq_earn_4qma_p99 fq_earn_4qma_p95 fq_earn_4qma_p90 fq_earn_4qma_n 5
               avg_fq_earn_4qma female_avg_fq_earn_4qma allemp_avg_fq_earn_4qma 5 ;
    merge sein_earn_thresh&i. (rename=(fq_earn_4qma_max=fq_earn_4qma_top1 fq_earn_4qma_fwd_max=fq_earn_4qma_fwd_top1) drop=fq_earn_4qma_fwd_p99 fq_earn_4qma_fwd_p95 fq_earn_4qma_fwd_p90 fq_earn_4qma_fwd_n )
          tmp_fq_earn_long&i.;
    by sein qtime;
    retain counter fq_earn_4qma_top3 male_emp_cnt female_emp_cnt male_bp90_cnt female_bp90_cnt tot_male_fq_earn tot_female_fq_earn;
            
    array top_female_cnt {5} _temporary_;
    array top_male_cnt   {5} _temporary_;
    array total_top {5};

    if _n_ = 1 then do;
        declare hash pik_sex (dataset:"lehd_t13.icf_us", hashexp:16);
            pik_sex.defineKey('pik');
            pik_sex.defineData('sex', 'dob');
            pik_sex.defineDone();
    
    end;

    if fq_earn_4qma_n < &top1_min_fsize. then delete;
    else do;
    
        if first.qtime then do;
            counter = 0;
            
            do i = 1 to 5;
                top_female_cnt{i} = 0;
                top_male_cnt{i} = 0;
            end;
                
            fq_earn_4qma_top3 = .;
            
            male_emp_cnt = 0;
            female_emp_cnt = 0;
            male_bp90_cnt = 0;
            female_bp90_cnt = 0;
            tot_male_fq_earn = 0;
            tot_female_fq_earn = 0;
        end;
    
        counter = counter + 1;
    
        if counter = 3 /*and fq_earn_4qma_n >= &top3_min_fsize.*/ then do;
            fq_earn_4qma_top3 = fq_earn_4qma;
        end;
                
        rc = pik_sex.find();
            
        * increment emp counts and earn totals;
        if sex = 'M' and fq_earn_4qma > 0 then do;
            male_emp_cnt = male_emp_cnt + 1;
            if fq_earn_4qma_p90 ~= . and fq_earn_4qma < fq_earn_4qma_p90 then male_bp90_cnt = male_bp90_cnt + 1;
            tot_male_fq_earn = tot_male_fq_earn + fq_earn_4qma;
        end;
        else if sex = 'F' and fq_earn_4qma > 0 then do;
            female_emp_cnt = female_emp_cnt + 1;
            if fq_earn_4qma_p90 ~= . and fq_earn_4qma < fq_earn_4qma_p90 then female_bp90_cnt = female_bp90_cnt + 1;
            tot_female_fq_earn = tot_female_fq_earn + fq_earn_4qma;            
        end;
            
        * increment sex count if top earner;
                
        if fq_earn_4qma_top1 ~= . and fq_earn_4qma >= fq_earn_4qma_top1 then do;
            if sex = 'M' then top_male_cnt{1} = 1 + top_male_cnt{1};
            else if sex = 'F' then top_female_cnt{1} = 1+ top_female_cnt{1};  
    
            * output the pik record to the top earner pik file;
            output sein_top_earner_pik&i.;
        end;
        * determine if top earner going forward;                
        if fq_earn_4qma_fwd_top1 ~= . and fq_earn_4qma_fwd >= fq_earn_4qma_fwd_top1 then do;
    
            * output the pik record to the top earner pik file;
            output sein_top_earner_fwd_pik&i.;
        end;
    
    
        if (fq_earn_4qma_top3 ~= . and fq_earn_4qma >= fq_earn_4qma_top3) or (counter < 3) then do;
            if sex = 'M' then top_male_cnt{2} = 1 + top_male_cnt{2};
            else if sex = 'F' then top_female_cnt{2} = 1+ top_female_cnt{2};     
        end;
        if fq_earn_4qma_p99 ~= . and fq_earn_4qma >= fq_earn_4qma_p99 then do;
            if sex = 'M' then top_male_cnt{3} = 1 + top_male_cnt{3};
            else if sex = 'F' then top_female_cnt{3} = 1+ top_female_cnt{3};     
        end;
        if fq_earn_4qma_p95 ~= . and fq_earn_4qma >= fq_earn_4qma_p95 then do;
            if sex = 'M' then top_male_cnt{4} = 1 + top_male_cnt{4};
            else if sex = 'F' then top_female_cnt{4} = 1+ top_female_cnt{4};     
        end;
        if fq_earn_4qma_p90 ~= . and fq_earn_4qma >= fq_earn_4qma_p90 then do;
            if sex = 'M' then top_male_cnt{5} = 1 + top_male_cnt{5};
            else if sex = 'F' then top_female_cnt{5} = 1+ top_female_cnt{5};     
        end;
            
        if last.qtime then do;
            do i = 1 to 5;
                total_top{i} = top_male_cnt{i} + top_female_cnt{i};
            end;
                
            * calculate the sex ratios for the different thresholds;
            if total_top{1} > 0 then top1_F_ratio = top_female_cnt{1} / total_top{1};
            if total_top{2} > 0 then top3_F_ratio = top_female_cnt{2} / total_top{2};
            if total_top{3} > 0 then p99_F_ratio  = top_female_cnt{3} / total_top{3};
            if total_top{4} > 0 then p95_F_ratio  = top_female_cnt{4} / total_top{4};
            if total_top{5} > 0 then p90_F_ratio  = top_female_cnt{5} / total_top{5};
            
            if female_emp_cnt + male_emp_cnt > 0 then do;
                allemp_F_ratio = female_emp_cnt / (female_emp_cnt + male_emp_cnt);
                allemp_avg_fq_earn_4qma = (tot_male_fq_earn + tot_female_fq_earn) / (male_emp_cnt + female_emp_cnt);
            end;
            else  allemp_F_ratio = .; 
                
            if male_bp90_cnt + female_bp90_cnt > 0 then do;
                bp90_F_ratio = female_bp90_cnt / (male_bp90_cnt + female_bp90_cnt);
            end;
            else  bp90_F_ratio = .; 
                
            if male_emp_cnt > 0 then male_avg_fq_earn_4qma = tot_male_fq_earn / male_emp_cnt;
            if female_emp_cnt > 0 then female_avg_fq_earn_4qma = tot_female_fq_earn / female_emp_cnt;
                
                
            output sein_top_earner_thresholds&i.;
            
        end;
    end;
    

run;    
        
            %end;
%mend;
%gen_top;
        
data interwrk.sein_top_earner_pik;
    set sein_top_earner_pik1
        sein_top_earner_pik2
        sein_top_earner_pik3
        sein_top_earner_pik4
        sein_top_earner_pik5;
run;
data interwrk.sein_top_earner_fwd_pik;
    set sein_top_earner_fwd_pik1
        sein_top_earner_fwd_pik2
        sein_top_earner_fwd_pik3
        sein_top_earner_fwd_pik4
        sein_top_earner_fwd_pik5;
run;
    
data interwrk.sein_top_earner_thresholds;
    set sein_top_earner_thresholds1
        sein_top_earner_thresholds2
        sein_top_earner_thresholds3
        sein_top_earner_thresholds4
        sein_top_earner_thresholds5;
run;
            
proc contents data=interwrk.sein_top_earner_pik;
proc print data=interwrk.sein_top_earner_pik(obs=20);
            
proc contents data=interwrk.sein_top_earner_thresholds;
proc print data=interwrk.sein_top_earner_thresholds(obs=100 where=(fq_earn_4qma_n > 1));
            
proc freq data=interwrk.sein_top_earner_thresholds;
    table top1_f_ratio top3_f_ratio;
run;
