/*********************************************************************************************

	WRITTEN BY: SETH MURRAY
		 Identify parents at SEINs with manager transitions, calculate those parents earnings histories surrounding their childbirth event if it occurred within 5 years of the manager transition time

	OUTPUT DATASETS:
		- interwrk.mngr_tr_earning_hist 
*********************************************************************************************/

    
%let max_n_fid = 200;
%let num_obs = max;
    

* get all parents at SEINs with manager transitions;

data parents_set(keep=pik sein transition_qtime transition_sex transition_type new_mngr_tenure_bck);
    length e1-e20 5 transition_qtime 3 birth_qtime 3 transition_sex $2 transition_type $2 new_mngr_tenure_bck 3;
    set lehd_t13.phf_interleave_b (obs=&num_obs. keep=pik fid sein e21-e&last_qtime.);
    where pik ~= "000000000";   
    
    array earn {&last_qtime.} e1-e&last_qtime.;
    
    if _n_ = 1 then do;
            declare hash sein_trans (dataset:"interwrk.top_earner_transitions",hashexp:16,multidata:"Y");
                sein_trans.defineKey('sein');
                sein_trans.defineData('transition_qtime','transition_type','transition_sex','new_mngr_tenure_bck');
                sein_trans.defineDone();
            
            declare hash parents_h (dataset:"interwrk.parentchild",hashexp:16,multidata:"Y");
                parents_h.defineKey('pik');
                parents_h.defineData('birth_qtime');
                parents_h.defineDone();
                
    end;


        
    rc = sein_trans.find();
    do while(rc = 0);
        
        has_earn = 0;
        if earn{transition_qtime} > 0 then has_earn = 1;
        is_new_parent = 0;
        
        do i = 1 to 20;
            if earn{transition_qtime-i} > 0 then do;
                has_earn = has_earn + 1;
                rc_parent = parents_h.find();
                do while(rc_parent = 0);
                    if birth_qtime <= transition_qtime - i and birth_qtime >= transition_qtime-i-4 then is_new_parent = 1;
                    rc_parent = parents_h.find_next();
                end;
            end;
            if earn{min(&last_qtime.,transition_qtime+i)} > 0 then do;
                has_earn = has_earn + 1;
                rc_parent = parents_h.find();
                do while(rc_parent = 0);
                    if birth_qtime <= transition_qtime + i and birth_qtime >= transition_qtime+i-4 then is_new_parent = 1;
                    rc_parent = parents_h.find_next();
                end;
            end;
        end;
            
        * require  at least 4 quarters of earnings at the firm;
        if has_earn >= 4 and is_new_parent = 1 then output;
                    
        rc = sein_trans.find_next();
    end;
    
run;




* generate parent only version of phf;
        
proc sort data=parents_set
          out=parents_set_nodup
          NODUPKEY;
    BY PIK;
run;
     
data parents_phf(drop=rc);
    length final_acs_year 4;
    set lehd_t13.phf_interleave_b (obs=&num_obs. keep=pik fid sein e21-e&last_qtime.);
    where pik ~= "000000000";         
    
    if _n_ = 1 then do;
            declare hash parents_h (dataset:"parents_set",hashexp:16);
                parents_h.defineKey('pik');
                parents_h.defineDone();
    end;
    
    rc = parents_h.check();
    if rc = 0 then output;
run;
        
    
proc sort data=parents_phf;
    by pik fid;
run;

proc print data=parents_phf (obs = 5);

data interwrk.mngr_tr_earning_hist (keep=pik transition_sein  birth_qtime  earn_fq earn_total 
                           earn_fq_fwd1-earn_fq_fwd20 earn_total_fwd1-earn_total_fwd20
                           earn_fq_bck1-earn_fq_bck12 earn_total_bck1-earn_total_bck12
                           tenure_bck emp_at_trans_fid_fwd1-emp_at_trans_fid_fwd20
                           birth_order marital_status PIK_partner mafid  new_mngr_tenure_bck transition_qtime transition_sex transition_type new_mngr_tenure_bck);
    length e1-e20 earn_fq earn_total 5 transition_sein $12 
           tenure_bck emp_at_trans_fid_fwd1-emp_at_trans_fid_fwd20 3
           birth_qtime 3 birth_order 3 marital_status $1 pik_partner mafid $9 hh_head $1 first_birth_qtime last_birth_qtime 3
           transition_qtime 3 transition_type $2 transition_sex $2 new_mngr_tenure_bck 3;
    set parents_phf (obs=&num_obs.);
    by pik fid;
    retain n_fid too_many_fid;

    array earn {&last_qtime.} e1-e&last_qtime.;
    
    array earn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array fqearn_by_fid {&max_n_fid., &last_qtime.} _temporary_;
    array sein_list {&max_n_fid., &last_qtime.} $12 _temporary_;
                            
    array fid_list{&max_n_fid.} 5 _temporary_;       

    array sein_match{&max_n_fid., &last_qtime.} $12 _temporary_;                 
    
    array earn_tot {&last_qtime.} _temporary_;
    array dom_fqearn_lvl {&last_qtime.} _temporary_;
    array fid_dom {&last_qtime.} 5 _temporary_;
                                       
    array earn_fq_fwd {20} 5;
    array earn_fq_bck {20} 5;
    array earn_total_fwd {20} 5;
    array earn_total_bck {20} 5;
    
    array emp_at_trans_fid_fwd {20} 3;                        
            
    if _n_ = 1 then do;
        n_fid = 1;     
                    
        declare hash parents_h (dataset:"interwrk.parentchild",hashexp:16,multidata:'Y');
            parents_h.defineKey('pik');
            parents_h.defineData('birth_qtime','birth_order','marital_status','pik_partner', 'mafid', 'hh_head');
            parents_h.defineDone();


        declare hash transition_h (dataset:"parents_set",hashexp:16,multidata:'Y');
            transition_h.defineKey('pik','sein');
            transition_h.defineData('transition_qtime', 'transition_type', 'transition_sex', 'new_mngr_tenure_bck');
            transition_h.defineDone();
    end;
    
    if first.pik then do;
        
        do i = &first_qtime. to &last_qtime.;
            dom_fqearn_lvl{i} = .;
            fid_dom{i} = .;
            earn_tot{i} = 0;
            do j = 1 to n_fid;
                earn_by_fid{j,i} = .;
                fqearn_by_fid{j,i} = .;
                sein_list{j,i} = "";
                sein_match{j,i} = "";
            end;
        
        end;
                
        do j = 1 to n_fid;
            fid_list{j} = .;     
        end;
        n_fid = 1;
        too_many_fid = 0;
    
    end;
    else if first.fid and n_fid < &max_n_fid. then do;
        if n_fid < &max_n_fid. then do;
            n_fid = n_fid + 1;      
        end;
        else too_many_fid = 1;
    end;
            
    fid_list{n_fid} = fid;
                
    rc_trans = transition_h.find();
    do while(rc_trans=0);
        sein_match{n_fid,transition_qtime} = sein;
        
        rc_trans = transition_h.find_next();            
    end;
                
    * accumulate earnings across the SEIN associated with the fid;            
    do qt = &first_qtime. to &last_qtime.;
         if earn{qt} > 0 then do;
            earn_by_fid{n_fid,qt} = sum(earn{qt},earn_by_fid{n_fid,qt} );
            sein_list{n_fid,qt} = sein;
            earn_tot{qt} = earn_tot{qt} + earn{qt};                           
         end;                                   
    end;
    
    * identify full-quarter earnings;
    if last.fid  then do;                        
        do qt = &first_qtime. to &last_qtime. - 1;
            if earn_by_fid{n_fid,qt} > 0 then do;
                * if full quarter earnings across all sein for this fid;
                if earn_by_fid{n_fid,qt-1} > 0 and earn_by_fid{n_fid,qt+1} > 0 then do;
   
                    fqearn_by_fid{n_fid,qt} = earn_by_fid{n_fid,qt};
                    * check if this is the dominant earnings;
                    if earn_by_fid{n_fid,qt} > dom_fqearn_lvl{qt} then do;
                        fid_dom{qt} = fid;
                        dom_fqearn_lvl{qt} = earn_by_fid{n_fid,qt};
                    end;
                end;
            end;   
        end;                    
    end;
                    
    if last.pik = 1 and too_many_fid = 0 then do;
        
        do f_num = 1 to n_fid;
            do qt = 21 to &last_qtime.;
                * if this SEIN has a transition;
                if sein_match{f_num,qt} ~= ""  then do;
           
                    * find  all instances in which  parents give birth within 5 years of transition  qtime;
                    rc = parents_h.find();
                    do while(rc=0);         
                        if max(qt - 20, &first_qtime.)  <= birth_qtime <= min(qt + 20, &last_qtime.)  then do;
                            tenure_bck = .;
                            transition_fid = .;
                            transition_sein = sein_match{f_num,qt};
                            earn_fq = .;
                            earn_total = .;
                            do i = 1 to 20;
                                earn_fq_fwd{i} = .;
                                earn_fq_bck{i} = .;
                                earn_total_fwd{i} = .;
                                earn_total_bck{i} = .;
                                emp_at_trans_fid_fwd{i} = .;
                            end;
                            
                            * if gave was full-quarter employed by transition employer  4  quarters  before birth;
                            if earn_by_fid{f_num,birth_qtime-5} > 0 and earn_by_fid{f_num,birth_qtime-4} > 0 and earn_by_fid{f_num,birth_qtime-3} > 0 then do;
                                
                                * calculate the full-quarter earnings at transition employer and total earnings +/- 20 quarters fwd and bck from one year before birth;                               
                                earn_fq = fqearn_by_fid{f_num,birth_qtime-4};
                                earn_total = earn_tot{birth_qtime - 4};
                                do i = 1 to 20;
                                    if birth_qtime -4 + i < &last_qtime. then do;
                                        earn_fq_fwd{i} = fqearn_by_fid{f_num,birth_qtime-4+i};
                                        earn_total_fwd{i} = earn_tot{birth_qtime-4+i};
                                    end;
                                    else do;
                                        earn_fq_fwd{i} = .;
                                        earn_total_fwd{i} = .;
                                    end;
                    
                                    if birth_qtime - i - 4 > &first_qtime. then do;
                                        earn_fq_bck{i} = fqearn_by_fid{f_num,birth_qtime-4-i} ;
                                        earn_total_bck{i} = earn_tot{birth_qtime-4-i};
                                    end;
                                    else do;
                                        earn_fq_bck{i} = .;
                                        earn_total_bck{i} = .;
                                    end;
                                end;
                                
                                * calculate tenure back and employment status fwd at the transition employer 1 year before birth;

                                if birth_qtime - 4 <= &first_qtime. then tenure_bck = .;
                                else do;
                                    tenure_bck = 0;
                                    do j = 1 to birth_qtime - 4 - &first_qtime.;
                                        if earn_by_fid{f_num,birth_qtime-j-4} > 0 then tenure_bck = tenure_bck + 1;
                                    end;
                    
                                    do j = 1 to 20;
                                        if birth_qtime - 4 + j < &last_qtime. then do;
                                            if earn_by_fid{f_num,birth_qtime -4 + j} > 0 then emp_at_trans_fid_fwd{j} = 1;
                                            else emp_at_trans_fid_fwd{j} = 0;
                                        end;
                                        else do;
                                            emp_at_trans_fid_fwd{j} = .;
                                        end;
                                    end;
                                end;         
                            
                                sein = transition_sein;
                
                                found_trans = 0;
                                rc_trans = transition_h.find();
                                do while(rc_trans=0 and found_trans=0);
                                    if transition_qtime = qt then do;
                                        found_trans = 1;
                                    end;
                               
                                    if found_trans = 0 then do;
                                        rc_trans = transition_h.find_next();   
                                    end;
                                end;
                  
                                label tenure_bck = "Workers tenure at transition SEIN one year before birth (qtime-4)"
                                    emp_at_trans_fid_fwd1 = "=1 if worker has positive earnings at transition employer in birth_qtime-4 one quarter later (= birth_qtimee -3)"
                                    transition_sein = "manager transitoin employer SEIN in birth_qtime";
            
                                *require at least 4 quarters of tenure at the dominant employer as of 1 year before birth;
                                if tenure_bck >=4 and found_trans = 1 then output;
                            end;
                        end;
            
                        rc = parents_h.find_next();
                    end;  
  
                end;
            end;
        end;
    end;

run;  

proc contents data=interwrk.mngr_tr_earning_hist;
proc print data=interwrk.mngr_tr_earning_hist(obs=100);                        

