/*********************************************************************************************

	WRITTEN BY: SETH MURRAY 
		 Calculates summary stats for the universe of establishments that describe the female share of top earners and the earnings ratio of men versus women by industry.

	OUTPUT DATASETS:
	       - outputs.F_shr_earner_qtime_wt
	       - outputs.f_shr_earner_wt
	       - outputs.f_shr_earner
	       - outputs.f_shr_earner_ind3_95v17_wt
	       - outputs.f_shr_earner_ind3_wt
*********************************************************************************************/



%let supdir = /support;    
%let num_obs = MAX;
*10000000;
    
data tmp_for_freqs ;
    set interwrk.sein_characteristics(obs=&num_obs.);
    
    industry_2d = substr(naics,1,2);
    industry_3d = substr(naics,1,3);
    industry_4d = substr(naics,1,4);
    
    if fq_earn_4qma_n < &p99_min_fsize. then p99_f_ratio = .;
    if fq_earn_4qma_n < &p95_min_fsize. then p95_f_ratio = .;
    if fq_earn_4qma_n < &p90_min_fsize. then p90_f_ratio = .;
    if fq_earn_4qma_n < &top3_min_fsize. then top3_f_ratio = .;
    if fq_earn_4qma_n < &top1_min_fsize. then top1_f_ratio = .;
    
    if firmsize <= 19 then fsz = "000to019";
    else if firmsize <= 49 then fsz = "020to049";
    else if firmsize <= 249 then fsz = "050to249";
    else if firmsize <= 499 then fsz = "250to499";
    else if firmsize > 500 then fsz = "500+";
    
    if 0 <= firmage <= 1 then fage = "00to01";
    else if firmage <= 3 then fage = "02to03";
    else if firmage <= 5 then fage = "04to05";
    else if firmage <= 10 then fage = "06to10";
    else if firmage > 10 then fage = "11+";
    
    if female_avg_fq_earn_4qma > 0 and male_avg_fq_earn_4qma > 0 then do;
        f_m_avg_fqearn_ratio = female_avg_fq_earn_4qma/ male_avg_fq_earn_4qma;
    end;

    sein_state = substr(sein,1,2);
	
	*disclosure stats;
	female_count_top3 = floor(top3_f_ratio*3);
	male_count_top3 = 3-female_count_top3;
	year_flag=0;
		IF ( 129 <= qtime <= 133 ) THEN year_flag=2007;
		IF ( 41 <= qtime <= 44 ) THEN year_flag=1995;
	female_count_top1 = floor(top1_f_ratio);
	male_count_top1 = 1-female_count_top1;
run;

PROC FREQ DATA=tmp_for_freqs;
	TITLE "counts for disclosure";
	TABLES female_count_top3 male_count_top3 year_flag /MISSING;
RUN;

PROC SORT DATA=tmp_for_freqs(WHERE=( (year_flag=1995 OR year_flag=2007) AND female_count_top3^=. AND industry_3d ~= "" and industry_3d ~= "927" and industry_3d ~= "482")) OUT=temp_disclsoure;
	BY year_flag industry_3d;
RUN;

PROC MEANS DATA=temp_disclsoure(WHERE=(female_count_top3^=.)) NOPRINT;
	BY year_flag industry_3d;
	VAR female_count_top3 male_count_top3;
	OUTPUT OUT=temp_disclsoure(KEEP=year_flag industry_3d female_count_top3 male_count_top3)
		SUM(female_count_top3)=female_count_top3
		SUM(male_count_top3)=male_count_top3;
RUN;

proc export data=temp_disclsoure
            outfile="&supdir./for_fig_F_top3_ind3_1995v2017_indcounts.csv"
            dbms=csv
            replace;
run;

PROC SORT DATA=tmp_for_freqs(WHERE=(female_count_top3^=.)) OUT=temp_disclsoure;
	BY industry_3d;
RUN;

PROC MEANS DATA=temp_disclsoure(WHERE=(female_count_top3^=.)) NOPRINT;
	BY industry_3d;
	VAR female_count_top3 male_count_top3;
	OUTPUT OUT=temp_disclsoure(KEEP=industry_3d female_count_top3 male_count_top3)
		SUM(female_count_top3)=female_count_top3
		SUM(male_count_top3)=male_count_top3;
RUN;

proc export data=temp_disclsoure
            outfile="&supdir./for_fig_F_top3_earnratio_ind3_indcounts.csv"
            dbms=csv
            replace;
run;

PROC SORT DATA=tmp_for_freqs(WHERE=(female_count_top1^=.)) OUT=temp_disclsoure;
	BY qtime;
RUN;

PROC MEANS DATA=temp_disclsoure NOPRINT;
	BY qtime;
	VAR female_count_top1 male_count_top1;
	OUTPUT OUT=temp_disclsoure(KEEP=qtime female_count_top1 male_count_top1)
		SUM(female_count_top1)=female_count_top1
		SUM(male_count_top1)=male_count_top1;
RUN;

proc export data=temp_disclsoure
            outfile="&supdir./top_f_shr_qtime_indcounts.csv"
            dbms=csv
            replace;
run;

proc means data=tmp_for_freqs  mean;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio ;
    output out=outputs.F_shr_earner mean= n= /autoname;
run;
    
proc means data=tmp_for_freqs  mean;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=outputs.F_shr_earner_wt mean= n= /autoname;
run;
    
    
* By Qtime;
proc summary data=tmp_for_freqs;
    class qtime;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=outputs.F_shr_earner_qtime_wt mean= n= /autoname;
run;
    
proc sort data=outputs.F_shr_earner_qtime_wt;
    by qtime;
run;
    
ods graphics on /reset imagename="F_shr_top_earner_qtime" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_qtime_wt;
    series x=qtime y=top1_f_ratio_mean /lineattrs=(pattern=Solid);
    series x=qtime y=top3_f_ratio_mean;
    series x=qtime y=p99_f_ratio_mean;
    series x=qtime y=p95_f_ratio_mean;
    series x=qtime y=p90_f_ratio_mean;
run;     
ods graphics off;

* state count by industry and  qtime;
proc  sort  data=tmp_for_freqs
            out=tmp_for_freqs_sorted;
    by qtime industry_3d;
run;

proc freq data=tmp_for_freqs_sorted (where=(p99_f_ratio~=.));
    by qtime industry_3d;
    table sein_state /out=outputs.F_shr_earn_qtime_st_cnts;
run;
    
    
* By 2-digit Industry;
proc means data=tmp_for_freqs  mean;
    class industry_2d;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio ;
    output out=outputs.F_shr_earner_ind mean= n= /autoname;
run;

proc means data=tmp_for_freqs  mean;
    class industry_2d;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=outputs.F_shr_earner_ind2_wt mean= n= /autoname;
run;
    
* By 3-digit Industry;
proc summary data=tmp_for_freqs  mean;
    class industry_3d;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=outputs.F_shr_earner_ind3_wt mean= n= /autoname;
run;

proc print data=outputs.F_shr_earner_ind3_wt;
    var industry_3d top1_f_ratio_mean bp90_f_ratio_mean f_m_avg_fqearn_ratio_mean;
run;
        

ods graphics on /reset imagename="F_shr_top1_earner_ind3" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_ind3_wt;
    scatter x=bp90_f_ratio_mean y=top1_f_ratio_mean /markerattrs=(symbol=CircleFilled);
run;     
ods graphics off;
        
ods graphics on /reset imagename="F_shr_top3_earner_ind3" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_ind3_wt;
    scatter x=bp90_f_ratio_mean y=top3_f_ratio_mean /markerattrs=(symbol=CircleFilled);
run;     
ods graphics off;
        
ods graphics on /reset imagename="F_shr_p95_earner_ind3" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_ind3_wt;
    scatter x=bp90_f_ratio_mean y=p95_f_ratio_mean /markerattrs=(symbol=CircleFilled);
run;     
ods graphics off;

ods graphics on /reset imagename="F_shr_p95_by_fm_earn_ratio_ind3" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_ind3_wt;
    scatter x=p95_f_ratio_mean y=f_m_avg_fqearn_ratio_mean /markerattrs=(symbol=CircleFilled);
run;     
ods graphics off;

ods graphics on /reset imagename="F_shr_top1_by_fm_earn_ratio_ind3" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_ind3_wt;
    scatter x=top1_f_ratio_mean y=f_m_avg_fqearn_ratio_mean /markerattrs=(symbol=CircleFilled);
run;     
ods graphics off;
        
* Change in F_shr over time by industry (1995 versus 2017);
proc summary data=tmp_for_freqs (where=( 41 <= qtime <= 44));
    class industry_3d;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=tmp_ind3_fshr_1995 mean= n= /autoname;
run;
    
proc summary data=tmp_for_freqs (where=( 129 <= qtime <= 133));
    class industry_3d;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=tmp_ind3_fshr_2017 mean= n= /autoname;
run;    
    
proc sort data=tmp_ind3_fshr_1995;
    by industry_3d;
run;
    
proc sort data=tmp_ind3_fshr_2017;
    by industry_3d;
run;
   
PROC CONTENTS DATA=tmp_ind3_fshr_1995;
RUN;

PROC CONTENTS DATA=tmp_ind3_fshr_2017;
RUN;

   
data outputs.F_shr_earner_ind3_95v17_wt;
    merge tmp_ind3_fshr_1995 (rename=(top1_f_ratio_mean=top1_f_ratio_1995 top3_f_ratio_mean=top3_f_ratio_1995
                                      p99_f_ratio_mean=p99_f_ratio_1995 p95_f_ratio_mean=p95_f_ratio_1995 
                                      p90_f_ratio_mean=p90_f_ratio_1995
                                      allemp_f_ratio_mean=allemp_f_ratio_1995 bp90_f_ratio_mean=bp90_f_ratio_1995 
                                      f_m_avg_fqearn_ratio_mean=f_m_avg_fqearn_ratio_1995 top3_f_ratio_n=count_top3_1995 
                                      f_m_avg_fqearn_ratio_n=count_fm_ratio_1995))
          tmp_ind3_fshr_2017 (rename=(top1_f_ratio_mean=top1_f_ratio_2017 top3_f_ratio_mean=top3_f_ratio_2017
                                      p99_f_ratio_mean=p99_f_ratio_2017 p95_f_ratio_mean=p95_f_ratio_2017 
                                      p90_f_ratio_mean=p90_f_ratio_2017
                                      allemp_f_ratio_mean=allemp_f_ratio_2017 bp90_f_ratio_mean=bp90_f_ratio_2017 
                                      f_m_avg_fqearn_ratio_mean=f_m_avg_fqearn_ratio_2017 top3_f_ratio_n=count_top3_2017 
                                      f_m_avg_fqearn_ratio_n=count_fm_ratio_2017));
    by industry_3d;
    
    top1_f_shr_chg_pp  = top1_f_ratio_2017 - top1_f_ratio_1995;
    top1_f_shr_chg_per = top1_f_shr_chg_pp / top1_f_ratio_1995;
                        
    top3_f_shr_chg_pp  = top3_f_ratio_2017 - top3_f_ratio_1995;
    top3_f_shr_chg_per = top3_f_shr_chg_pp / top3_f_ratio_1995;  


    p99_f_shr_chg_pp  = p99_f_ratio_2017 - p99_f_ratio_1995;
    p99_f_shr_chg_per = p99_f_shr_chg_pp / p99_f_ratio_1995;

    p95_f_shr_chg_pp  = p95_f_ratio_2017 - p95_f_ratio_1995;
    p95_f_shr_chg_per = p95_f_shr_chg_pp / p95_f_ratio_1995;

    p90_f_shr_chg_pp  = p90_f_ratio_2017 - p90_f_ratio_1995;
    p90_f_shr_chg_per = p90_f_shr_chg_pp / p90_f_ratio_1995; 

    allemp_f_shr_chg_pp  = allemp_f_ratio_2017 - allemp_f_ratio_1995;
    allemp_f_shr_chg_per = allemp_f_shr_chg_pp / allemp_f_ratio_1995; 

    f_m_earn_ratio_chg_pp  = f_m_avg_fqearn_ratio_2017 - f_m_avg_fqearn_ratio_1995;
    f_m_earn_ratio_chg_per = f_m_earn_ratio_chg_pp / f_m_avg_fqearn_ratio_1995;                                
run;

proc corr data=outputs.F_shr_earner_ind3_95v17_wt pearson;
    var top1_f_shr_chg_pp p95_f_shr_chg_pp f_m_earn_ratio_chg_pp;
run;
    
proc corr data=outputs.F_shr_earner_ind3_95v17_wt pearson;
    var top1_f_shr_chg_per p95_f_shr_chg_per f_m_earn_ratio_chg_per;
run;


ods graphics on /reset imagename="F_shr_top1_ind3_95v17" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_ind3_95v17_wt;
    scatter x=bp90_f_ratio_1995 y=top1_f_ratio_1995 /markerattrs=(symbol=CircleFilled)  ;
    scatter x=bp90_f_ratio_2017 y=top1_f_ratio_2017 /markerattrs=(symbol=TriangleFilled) ;
run;     
ods graphics off;



ods graphics on /reset imagename="F_shr_top1_chg_ind3_95v17" imagefmt=pdf;
ods listing gpath = "&figure_path.";
proc sgplot data=outputs.F_shr_earner_ind3_95v17_wt;
    scatter x=top1_f_ratio_1995 y=top1_f_ratio_2017 /markerattrs=(symbol=CircleFilled)  ;
run;     
ods graphics off;


proc print data=outputs.F_shr_earner_ind3_95v17_wt;
    var industry_3d top1_f_shr_chg_pp top3_f_shr_chg_pp p99_f_shr_chg_pp p95_f_shr_chg_pp p90_f_shr_chg_pp allemp_f_shr_chg_pp f_m_earn_ratio_chg_pp;
run;
    
proc print data=outputs.F_shr_earner_ind3_95v17_wt;
    var industry_3d top1_f_shr_chg_per top3_f_shr_chg_per p99_f_shr_chg_per p95_f_shr_chg_per p90_f_shr_chg_per allemp_f_shr_chg_per f_m_earn_ratio_chg_per;
run;    
    

* By Firm Size;
proc means data=tmp_for_freqs  mean;
    class fsz;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio ;
    output out=outputs.F_shr_earner_fsz mean= n= /autoname;
run;
    
proc means data=tmp_for_freqs  mean;
    class fsz;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=outputs.F_shr_earner_fsz_wt mean= n= /autoname;
run;
    
* By Firm Age;
proc means data=tmp_for_freqs  mean;
    class fage;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio ;
    output out=outputs.F_shr_earner_fage mean= n= /autoname;
run;
    
proc means data=tmp_for_freqs  mean;
    class fage;
    weight fq_earn_4qma_n;
    var top1_f_ratio top3_f_ratio p99_f_ratio p95_f_ratio p90_f_ratio allemp_f_ratio bp90_f_ratio f_m_avg_fqearn_ratio;
    output out=outputs.F_shr_earner_fage_wt mean= n= /autoname;
run;
    
